@@ -1,11 +1,14 @@
-# Copyrights 1999,2001-2015 by [Mark Overmeer].
+# Copyrights 1999-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution MIME::Types.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '2.10';
+$VERSION = '2.20';
 
 
 use strict;
@@ -167,7 +170,7 @@ sub httpAccept($)
           $ !x or next;
 
         my $mime = "$1/$2$4";
-        my $q    = $3 // 1;   # q, default=1
+        my $q    = defined $3 ? $3 : 1;   # q, default=1
 
         # most complex first
         $q += $4 ? +0.01 : $1 eq '*' ? -0.02 : $2 eq '*' ? -0.01 : 0;
@@ -275,10 +278,3 @@ CROAK
 }
 
 1;
-__END__
-# Exceptions
-vms:text/plain;doc;8bit
-mac:application/x-macbase64;;bin
-
-# IE6 bug
-image/pjpeg;;base64
